@@ -1,4 +1,4 @@
-/* $Id: error.h,v 1.3 1998/06/14 16:47:07 martin Exp $ */
+/* $Id: error.h,v 1.4 1999/02/15 21:22:50 jgarzik Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -26,6 +26,11 @@
 
 __BEGIN_DECLS
 
+/*
+ * FIXME: varargs macros only supported on gcc.
+ *	  Breaks Sun CC, maybe others.
+ */
+
 #define glibtop_error(p1, args...)	glibtop_error_r(glibtop_global_server , p1 , ## args)
 #define glibtop_warn(p1, args...)	glibtop_warn_r(glibtop_global_server , p1 , ## args)
 
