@@ -1,4 +1,4 @@
-/* $Id: daemon.h,v 1.3 1998/12/09 21:28:43 martin Exp $ */
+/* $Id: daemon.h,v 1.4 1998/12/11 08:24:44 devernay Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -39,6 +39,11 @@
 
 __BEGIN_DECLS
 
+/* Some don't have LOG_PERROR */
+#ifndef LOG_PERROR
+#define LOG_PERROR 0
+#endif
+
 #if defined(HAVE_GETDTABLESIZE)
 #define GET_MAX_FDS() getdtablesize()
 #else
