@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: error.c,v 1.6 1998/11/11 16:02:01 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -21,23 +21,36 @@
 
 #include <glibtop/error.h>
 
-#define DEFAULT_NAME	"ERROR"
+#define DEFAULT_NAME	"LibGTop-Server"
 
 /* Prints error message and exits. */
 
+static void
+print_server_name (glibtop *server)
+{
+	fprintf (stderr, "%s: ", server ? 
+		 (server->name ? server->name : DEFAULT_NAME)
+		 : DEFAULT_NAME);
+}
+
 void
 glibtop_error_r (glibtop *server, char *format, ...)
 {
 	va_list	ap;
 	
 	va_start (ap, format);
-	
-	fprintf (stderr, "%s: ", server ? server->name : DEFAULT_NAME);
+
+	print_server_name (server);	
 	vfprintf (stderr, format, ap);
 	fprintf (stderr, "\n");
 	
 	va_end (ap);
+
+#ifdef LIBGTOP_ENABLE_DEBUG
+	abort ();
+#else
 	exit (1);
+#endif
 }
 
 void
@@ -47,12 +60,17 @@ glibtop_error_io_r (glibtop *server, char *format, ...)
 	
 	va_start (ap, format);
 	
-	fprintf (stderr, "%s: ", server ? server->name : DEFAULT_NAME);
+	print_server_name (server);
 	vfprintf (stderr, format, ap);
 	fprintf (stderr, ": %s\n", strerror (errno));
 	
 	va_end (ap);
+
+#ifdef LIBGTOP_ENABLE_DEBUG
+	abort ();
+#else
 	exit (1);
+#endif
 }
 
 void
@@ -62,23 +80,31 @@ glibtop_warn_r (glibtop *server, char *format, ...)
 	
 	va_start (ap, format);
 	
-	fprintf (stderr, "%s: ", server ? server->name : DEFAULT_NAME);
+	print_server_name (server);
 	vfprintf (stderr, format, ap);
 	fprintf (stderr, "\n");
 	
 	va_end (ap);
+
+#ifdef LIBGTOP_FATAL_WARNINGS
+	abort ();
+#endif
 }
 
 void
 glibtop_warn_io_r (glibtop *server, char *format, ...)
 {
 	va_list	ap;
-	
+
 	va_start (ap, format);
 	
-	fprintf (stderr, "%s: ", server ? server->name : DEFAULT_NAME);
+	print_server_name (server);
 	vfprintf (stderr, format, ap);
 	fprintf (stderr, ": %s\n", strerror (errno));
 	
 	va_end (ap);
+
+#ifdef LIBGTOP_FATAL_WARNINGS
+	abort ();
+#endif
 }
