@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.5 1998/08/24 19:55:33 martin Exp $ */
+/* $Id: proctime.c,v 1.9 1998/11/17 23:15:12 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -60,7 +60,6 @@ calcru(p, up, sp, ip)
 	quad_t totusec;
 	u_quad_t u, st, ut, it, tot;
 	long sec, usec;
-	struct timeval tv;
 
 	st = p->p_sticks;
 	ut = p->p_uticks;
@@ -72,15 +71,26 @@ calcru(p, up, sp, ip)
 		tot = 1;
 	}
 
+#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+
+	/* This was changed from a `struct timeval' into a `u_int64_t'
+	 * on FreeBSD 3.0 and renamed p_rtime -> p_runtime.
+	 */
+
+	totusec = (u_quad_t) p->p_runtime;
+#else
 	sec = p->p_rtime.tv_sec;
 	usec = p->p_rtime.tv_usec;
 
 	totusec = (quad_t)sec * 1000000 + usec;
 	if (totusec < 0) {
 		/* XXX no %qd in kernel.  Truncate. */
-		printf("calcru: negative time: %ld usec\n", (long)totusec);
+		fprintf (stderr, "calcru: negative time: %ld usec\n",
+			 (long)totusec);
 		totusec = 0;
 	}
+#endif
+
 
 	u = totusec;
 	st = (u * st) / tot;
@@ -105,21 +115,31 @@ glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 	struct kinfo_proc *pinfo;
 	struct user *u_addr = (struct user *)USRSTACK;
 	struct pstats pstats;
-	struct pcb pcb;
-	int f, count;
-	quad_t totusec;
+	int count;
+
+	char filename [BUFSIZ];
+	struct stat statb;
 
 	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_TIME), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_time));
 
-	glibtop_suid_enter (server);
+	if (server->sysdeps.proc_time == 0)
+		return;
+
+	/* It does not work for the swapper task. */
+	if (pid == 0) return;
+	
+	sprintf (filename, "/proc/%d/mem", pid);
+	if (stat (filename, &statb)) return;
 
 	/* Get the process information */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
 	if ((pinfo == NULL) || (count != 1))
 		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
 
+	glibtop_suid_enter (server);
+
 	if ((pinfo [0].kp_proc.p_flag & P_INMEM) &&
 	    kvm_uread (server->machine.kd, &(pinfo [0]).kp_proc,
 		       (unsigned long) &u_addr->u_stats,
@@ -133,7 +153,7 @@ glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 			register struct rusage *rup;
 
 			glibtop_suid_leave (server);
-			
+
 			rup = &pstats.p_ru;
 			calcru(&(pinfo [0]).kp_proc,
 			       &rup->ru_utime, &rup->ru_stime, NULL);
@@ -151,7 +171,11 @@ glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 
 	glibtop_suid_leave (server);
 
+#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+	buf->rtime = pinfo [0].kp_proc.p_runtime;
+#else
 	buf->rtime = tv2sec (pinfo [0].kp_proc.p_rtime);
+#endif
 
 	buf->frequency = 1000000;
 
