@@ -1,4 +1,4 @@
-/* $Id: sem_limits.c,v 1.4 1998/08/24 19:55:35 martin Exp $ */
+/* $Id: sem_limits.c,v 1.6 1998/12/05 18:52:07 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -27,7 +27,11 @@
 
 /* #define KERNEL to get declaration of `struct seminfo'. */
 
-#define KERNEL
+#ifdef __FreeBSD__
+#define KERNEL 1
+#else
+#define _KERNEL 1
+#endif
 
 #include <sys/ipc.h>
 #include <sys/sem.h>
@@ -55,14 +59,18 @@ static struct nlist nlst [] = {
 void
 glibtop_init_sem_limits_p (glibtop *server)
 {
-	server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
-
-	if (kvm_nlist (server->machine.kd, nlst) != 0)
-		glibtop_error_io_r (server, "kvm_nlist");
+	if (kvm_nlist (server->machine.kd, nlst) != 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (sem_limits)");
+		return;
+	}
 	
 	if (kvm_read (server->machine.kd, nlst [0].n_value,
-		      &_seminfo, sizeof (_seminfo)) != sizeof (_seminfo))
-		glibtop_error_io_r (server, "kvm_read (seminfo)");
+		      &_seminfo, sizeof (_seminfo)) != sizeof (_seminfo)) {
+		glibtop_warn_io_r (server, "kvm_read (seminfo)");
+		return;
+	}
+
+	server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
 }
 
 /* Provides information about sysv sem limits. */
@@ -74,6 +82,9 @@ glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
 	
 	memset (buf, 0, sizeof (glibtop_sem_limits));
 	
+	if (server->sysdeps.sem_limits == 0)
+		return;
+
 	buf->semmap = _seminfo.semmap;
 	buf->semmni = _seminfo.semmni;
 	buf->semmns = _seminfo.semmns;
