@@ -1,4 +1,4 @@
-/* $Id: loadavg.c,v 1.5 1998/08/16 13:38:31 martin Exp $ */
+/* $Id: loadavg.c,v 1.6 1999/01/22 15:36:35 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -23,7 +23,7 @@
 
 const char *glibtop_names_loadavg [GLIBTOP_MAX_LOADAVG] =
 {
-	"loadavg [3]", "nr_running", "nr_tasks", "last_pid"
+	"loadavg", "nr_running", "nr_tasks", "last_pid"
 };
 
 const unsigned glibtop_types_loadavg [GLIBTOP_MAX_LOADAVG] =
